@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -46,6 +46,9 @@ public abstract class AbstractMailFilterAction implements EnqueuableAJAXActionSe
     protected final ServiceLookup services;
     private static final String UserNameParameter = "username";
 
+    /** The module as used in restricted scopes for OAuth, aligned to <code>com.openexchange.mail.json.actions.AbstractMailAction.MODULE</code> */
+    protected static final String RESTRICTED_MODULE = "mail";
+
     /**
      * Initializes a new {@link AbstractMailFilterAction}.
      */
