@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@ import org.apache.jsieve.SieveException;
 import org.json.JSONArray;
 import org.json.JSONException;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.jsieve.commands.Rule;
 import com.openexchange.jsieve.commands.RuleComment;
 import com.openexchange.mail.filter.json.v2.json.fields.RuleField;
@@ -70,9 +71,9 @@ public class FlagsRuleFieldMapper implements RuleFieldMapper {
     @Override
     public void setAttribute(Rule rule, Object attribute, ServerSession session) throws JSONException, SieveException, OXException {
         JSONArray array = (JSONArray) attribute;
-        ArrayList<String> list = new ArrayList<String>(array.length());
+        ArrayList<String> list = new ArrayList<>(array.length());
         for (int i = 0; i < array.length(); i++) {
-            list.add(array.getString(i));
+            list.add(Strings.sanitizeString(array.getString(i)));
         }
         RuleComment ruleComment = rule.getRuleComment();
         if (null != ruleComment) {
