@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,6 +25,7 @@ import org.apache.jsieve.SieveException;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.jsieve.commands.Rule;
 import com.openexchange.jsieve.commands.RuleComment;
 import com.openexchange.mail.filter.json.v2.json.fields.RuleField;
@@ -68,10 +69,11 @@ public class RuleNameRuleFieldMapper implements RuleFieldMapper {
     @Override
     public void setAttribute(Rule rule, Object attribute, ServerSession session) throws JSONException, SieveException, OXException {
         RuleComment ruleComment = rule.getRuleComment();
+        String newName = Strings.sanitizeString((String) attribute);
         if (null != ruleComment) {
-            ruleComment.setRulename((String) attribute);
+            ruleComment.setRulename(newName);
         } else {
-            rule.setRuleComments(new RuleComment((String) attribute));
+            rule.setRuleComments(new RuleComment(newName));
         }
     }
 }
