@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,6 +29,8 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Filter;
+import com.openexchange.config.lean.DefaultProperty;
+import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.jsieve.commands.ActionCommand;
 import com.openexchange.jsieve.commands.ActionCommand.Commands;
@@ -75,9 +77,15 @@ public class RedirectActionCommandParser implements CommandParser<ActionCommand>
         }
         // And finally check of that forward address is allowed
         ConfigurationService service = Services.getService(ConfigurationService.class);
-        Filter filter;
-        if (null != service && (null != (filter = service.getFilterFromProperty("com.openexchange.mail.filter.redirectWhitelist"))) && !filter.accepts(stringParam)) {
-            throw MailFilterExceptionCode.REJECTED_REDIRECT_ADDRESS.create(stringParam);
+        LeanConfigurationService leanConfigurationService = Services.getService(LeanConfigurationService.class);
+        if (null != service && null != leanConfigurationService) {
+            String propertyValue = leanConfigurationService.getProperty(session.getUserId(), session.getContextId(), DefaultProperty.valueOf("com.openexchange.mail.filter.redirectWhitelist", null));
+            if (null != propertyValue) {
+                Filter filter = service.getFilterForValue(propertyValue);
+                if (null != filter && !filter.accepts(stringParam)) {
+                    throw MailFilterExceptionCode.REJECTED_REDIRECT_ADDRESS.create(stringParam);
+                }
+            }
         }
         argList.add(CommandParserJSONUtil.stringToList(stringParam));
         ActionCommand result = new ActionCommand(Commands.REDIRECT, argList);
