@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 import org.json.JSONException;
+import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.SessionUtility;
 import com.openexchange.ajax.container.Response;
 import com.openexchange.ajax.writer.ResponseWriter;
@@ -68,12 +69,6 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
 
     private static final String PARAMETER_SESSION = com.openexchange.ajax.AJAXServlet.PARAMETER_SESSION;
 
-    /**
-     * The content type if the response body contains javascript data. Set it
-     * with <code>resp.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT)</code>.
-     */
-    public static final String CONTENTTYPE_JAVASCRIPT = "text/javascript; charset=UTF-8";
-
     private CookieHashSource hashSource;
 
     protected AbstractMailFilterServlet() {
@@ -190,7 +185,7 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
          */
         Tools.disableCaching(resp);
         resp.setStatus(HttpServletResponse.SC_OK);
-        resp.setContentType(CONTENTTYPE_JAVASCRIPT);
+        AJAXServlet.setDefaultContentType(resp);
         try {
             ResponseWriter.write(response, resp.getWriter(), localeFrom(session));
         } catch (JSONException e) {
@@ -261,7 +256,7 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
          */
         Tools.disableCaching(resp);
         resp.setStatus(HttpServletResponse.SC_OK);
-        resp.setContentType(CONTENTTYPE_JAVASCRIPT);
+        AJAXServlet.setDefaultContentType(resp);
         try {
             ResponseWriter.write(response, resp.getWriter(), localeFrom(session));
         } catch (JSONException e) {
