@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -31,7 +31,6 @@ import java.io.InputStreamReader;
 import java.io.PushbackReader;
 import java.io.Reader;
 import java.io.UnsupportedEncodingException;
-import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.net.Socket;
 import java.net.SocketTimeoutException;
@@ -64,10 +63,12 @@ import com.openexchange.jsieve.export.utils.FailsafeCircuitBreakerBufferedOutput
 import com.openexchange.jsieve.export.utils.FailsafeCircuitBreakerBufferedReader;
 import com.openexchange.jsieve.export.utils.HostAndPort;
 import com.openexchange.mail.mime.QuotedInternetAddress;
+import com.openexchange.mail.utils.NetUtils;
 import com.openexchange.mailfilter.internal.CircuitBreakerInfo;
 import com.openexchange.mailfilter.properties.MailFilterProperty;
 import com.openexchange.mailfilter.properties.PreferredSASLMech;
 import com.openexchange.mailfilter.services.Services;
+import com.openexchange.net.ssl.config.SSLConfigurationService;
 import com.openexchange.tools.encoding.Base64;
 import io.micrometer.core.instrument.Metrics;
 import io.micrometer.core.instrument.Timer;
@@ -444,11 +445,14 @@ public class SieveHandler {
                 /*
                  * Switch to TLS
                  */
-                String[] protocols = Strings.splitByComma(MailFilterProperty.protocols.getDefaultValue().toString());
+                String[] protocols;
                 {
                     String sProtocols = mailFilterConfig.getProperty(userId, contextId, MailFilterProperty.protocols);
                     if (Strings.isNotEmpty(sProtocols)) {
                         protocols = Strings.splitByComma(sProtocols.trim());
+                    } else {
+                        SSLConfigurationService sslConfigService = Services.optService(SSLConfigurationService.class);
+                        protocols = sslConfigService == null ? NetUtils.getProtocolsArray() : sslConfigService.getSupportedProtocols();
                     }
                 }
                 s_sieve = SocketFetcher.startTLS(s_sieve, sieve_host, protocols);
@@ -541,7 +545,7 @@ public class SieveHandler {
         return new MetricHelper(this);
     }
 
-    private static final List<Class<? extends Exception>> NETWORK_COMMUNICATION_ERRORS = ImmutableList.of(
+    private static final List<Class<? extends Throwable>> NETWORK_COMMUNICATION_ERRORS = ImmutableList.of(
         java.net.SocketTimeoutException.class,
         java.io.EOFException.class);
 
@@ -1937,7 +1941,7 @@ public class SieveHandler {
             if (groupByEndpoints) {
                 String hostAddress;
                 try {
-                    hostAddress = InetAddress.getByName(sieveHandler.sieve_host).getHostAddress();
+                    hostAddress = com.openexchange.java.InetAddresses.forString(sieveHandler.sieve_host).getHostAddress();
                     host = hostAddress + ':' + sieveHandler.sieve_host_port;
                 } catch (@SuppressWarnings("unused") UnknownHostException e) {
                     // ignore;
