@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,9 @@
 package com.openexchange.jsieve.export;
 
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.jsieve.commands.ActionCommand.Commands.ENOTIFY;
+import static com.openexchange.jsieve.commands.ActionCommand.Commands.PGP_ENCRYPT;
+import static com.openexchange.jsieve.commands.ActionCommand.Commands.VACATION;
 import java.io.StringReader;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -53,9 +56,6 @@ import com.openexchange.mailfilter.Credentials;
 import com.openexchange.mailfilter.MailFilterInterceptorRegistry;
 import com.openexchange.mailfilter.exceptions.MailFilterExceptionCode;
 import com.openexchange.mailfilter.services.Services;
-import static com.openexchange.jsieve.commands.ActionCommand.Commands.ENOTIFY;
-import static com.openexchange.jsieve.commands.ActionCommand.Commands.PGP_ENCRYPT;
-import static com.openexchange.jsieve.commands.ActionCommand.Commands.VACATION;
 
 /**
  * This class will be used to filter out special things which are not part of
@@ -207,8 +207,8 @@ public final class SieveTextFilter {
     private static final String UNIQUE_ID = "UniqueId:";
 
     private static final String MATCH_STRING = "([^" + SEPARATOR_REGEX + "]*?)";
-
-    private static final Pattern PATTERN = Pattern.compile("^" + FLAG_TAG + MATCH_STRING + SEPARATOR_REGEX + UNIQUE_ID + MATCH_STRING + SEPARATOR_REGEX + RULENAME_TAG + "(.*?)$");
+    
+    private static final Pattern PATTERN = Pattern.compile("^" + FLAG_TAG + MATCH_STRING + SEPARATOR_REGEX + UNIQUE_ID + MATCH_STRING + SEPARATOR_REGEX + RULENAME_TAG + "([^|]*?)(?:" + SEPARATOR_REGEX + "|$)");
 
     private static final Pattern REQUIRE_PATTERN = Pattern.compile("(\"[a-z0-9\\.\\-]+\")+");
 
@@ -471,6 +471,7 @@ public final class SieveTextFilter {
 
     /**
      * Adds the proper require commands according to the actions used in the command within.
+     * 
      * @param rule The rule to add the require command to
      */
     public void addRequired(Rule rule) {
@@ -518,7 +519,7 @@ public final class SieveTextFilter {
             int minDiff = Integer.MAX_VALUE;
             Rule rightRule = null;
             for (final Rule rule : rules) {
-                final int abs = getPosDif (rule.getLinenumber() - ruleComment.getLine());
+                final int abs = getPosDif(rule.getLinenumber() - ruleComment.getLine());
                 if (abs < minDiff) {
                     minDiff = abs;
                     rightRule = rule;
@@ -618,7 +619,7 @@ public final class SieveTextFilter {
         return size;
     }
 
-    private int getPosDif (final int i) {
+    private int getPosDif(final int i) {
         return (i > 0) ? i : Integer.MAX_VALUE;
     }
 
@@ -646,11 +647,11 @@ public final class SieveTextFilter {
         for (int i = 0; i < stringToList.size(); i++) {
             final String line = stringToList.get(i);
             final Matcher matcher = PATTERN.matcher(line);
-            if (matcher.matches()) {
+            if (matcher.find()) {
                 final String flags = matcher.group(1);
                 if (flags.length() > 0) {
                     String errorText = null;
-                    final List<String> flagList = Arrays.asList(flags.split(","));
+                    final List<String> flagList = Arrays.asList(Strings.splitByComma(flags));
                     for (final String flag : flagList) {
                         final String illegal = flag.replaceAll(LEGAL_FLAG_CHARS, "");
                         if (illegal.length() > 0) {
@@ -756,7 +757,7 @@ public final class SieveTextFilter {
 
                 // Retain the commented state
                 if (rule.isCommented()) {
-                    String[] split = text.split(CRLF);
+                    String[] split = Strings.splitByLineSeparator(text);
                     StringBuilder sb = new StringBuilder();
                     for (String s : split) {
                         sb.append(COMMENT_TAG).append(s).append(CRLF);
@@ -988,12 +989,12 @@ public final class SieveTextFilter {
     }
 
     private ArrayList<String> stringToList(final String string) {
-        return new ArrayList<String>(Arrays.asList(string.split("\r?\n")));
+        return new ArrayList<String>(Arrays.asList(Strings.splitByLineSeparator(string)));
     }
 
     private List<String> stringToListComment(final String string) {
         final ArrayList<String> retval = new ArrayList<String>();
-        final String[] split = string.split("\r?\n");
+        final String[] split = Strings.splitByLineSeparator(string);
         for (final String line : split) {
             retval.add(COMMENT_TAG + line);
         }
@@ -1018,7 +1019,7 @@ public final class SieveTextFilter {
         mergeRequire.addAll(require);
         mergeRequire.addAll(writeBackRequire);
 
-        String[] splitWriteBack = writeback.split("\r?\n");
+        String[] splitWriteBack = Strings.splitByLineSeparator(writeback);
         // Script is empty, just return it
         if (splitWriteBack.length < 2) {
             return writeback;
@@ -1041,7 +1042,7 @@ public final class SieveTextFilter {
      * @return The set with the requires, or an empty set if no require line is present.
      */
     private Set<String> readRequire(String sieveScript) {
-        String[] split = sieveScript.split("\r?\n");
+        String[] split = Strings.splitByLineSeparator(sieveScript);
         // The require part is always located in line 2 of the script, i.e. the 1st element of the array
         if (split.length < 2 || !split[1].startsWith("require")) {
             return Collections.emptySet();
