@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,6 +30,7 @@ import java.security.PrivilegedAction;
 import javax.net.SocketFactory;
 import javax.net.ssl.SSLSocket;
 import javax.net.ssl.SSLSocketFactory;
+import com.openexchange.mail.utils.NetUtils;
 import com.openexchange.mailfilter.services.Services;
 import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 
@@ -150,11 +151,12 @@ public final class SocketFetcher {
 
     /**
      * Configure the SSL options for the socket (if it's an SSL socket).
+     * @throws OXException
      */
     private static void configureSSLSocket(Socket socket, String[] protocols) {
         if (socket instanceof SSLSocket) {
             final SSLSocket sslsocket = (SSLSocket) socket;
-            sslsocket.setEnabledProtocols(protocols == null || protocols.length <= 0 ? new String[] { "SSLv3", "TLSv1", "TLSv1.1", "TLSv1.2" } : protocols);
+            sslsocket.setEnabledProtocols(protocols == null || protocols.length <= 0 ? NetUtils.getProtocolsArray() : protocols);
         }
     }
 
