@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,7 +38,7 @@ import com.google.common.collect.ImmutableList;
  */
 public abstract class NetworkCommunicationErrorAdvertisingCallable<V> implements Callable<IOResult<V>> {
 
-    private static final List<Class<? extends Exception>> NETWORK_COMMUNICATION_ERRORS = ImmutableList.of(
+    private static final List<Class<? extends Throwable>> NETWORK_COMMUNICATION_ERRORS = ImmutableList.of(
         java.net.SocketTimeoutException.class,
         java.io.EOFException.class);
 
