@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -280,7 +280,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 throw MailFilterExceptionCode.NO_PROPERTIES_FILE_FOUND.create();
             }
             for (final MailFilterProperty property : MailFilterProperty.values()) {
-                if (!property.isOptional() && null == file.getProperty(property.getFQPropertyName())) {
+                if (!property.isOptional() && null == file.getProperty(property.getFQPropertyName()) && hasNoDefaultValue(property)) {
                     throw MailFilterExceptionCode.PROPERTY_NOT_FOUND.create(property.getFQPropertyName());
                 }
             }
@@ -289,8 +289,10 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
             } catch (NumberFormatException e) {
                 throw MailFilterExceptionCode.PROPERTY_ERROR.create("Property " + MailFilterProperty.connectionTimeout.getFQPropertyName() + " is not an integer value", e);
             }
-        } catch (IOException e) {
-            throw MailFilterExceptionCode.IO_ERROR.create(e.getMessage(), e);
+        } catch (OXException e) {
+            throw e;
+        } catch (Exception e) {
+            throw MailFilterExceptionCode.PROBLEM.create(e.getMessage(), e);
         }
 
         // Check password source
@@ -313,6 +315,11 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
         }
     }
 
+    private boolean hasNoDefaultValue(MailFilterProperty property) {
+        Object o = property.getDefaultValue();
+        return o == null ? true : (o instanceof String ? Strings.isEmpty((String) o) : false);
+    }
+
     /**
      * Closes given <tt>SieveHandler</tt> instance
      *
@@ -860,7 +867,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
     /**
      * Applies the optional <code>copy</code> required for the {@link ActionCommand.Commands#FILEINTO} and {@link ActionCommand.Commands#REDIRECT}
      * action commands.
-     * 
+     *
      * @param rule The rule
      * @return The rule
      */
